@@ -6,6 +6,7 @@ import numpy as np
 from PIL import Image
 
 from tofa._typing import image_like
+from tofa.bbox_utils import clip_bbox
 from tofa.torch_utils import as_numpy
 
 InterpolationValue = namedtuple("InterpolationValue", ("str", "opencv", "pil"))
@@ -60,7 +61,8 @@ class Interpolation(Enum):
 def image_size(image):
     """Returns image size (w x h)"""
     if _is_array(image):
-        return image.shape[:2]
+        h, w = image.shape[:2]
+        return w, h
     return image.size
 
 
@@ -117,7 +119,8 @@ def rescale(image: image_like, scale_factor, interpolation=Interpolation.DEAFULT
 
 
 def crop(image, position):
-    x1, y1, x2, y2 = map(int, position)
+    iw, ih = image_size(image)
+    x1, y1, x2, y2 = clip_bbox(position, iw, ih)
     if _is_array(image):
         return image[y1:y2, x1:x2]
     return image.crop((x1, y1, x2, y2))
